﻿using System;
using System.IO;
using ThinkGeo.MapSuite;
using ThinkGeo.MapSuite.iOS;
using ThinkGeo.MapSuite.Layers;
using ThinkGeo.MapSuite.Styles;
using UIKit;

namespace WmsAndWmts
{
    public partial class ViewController : UIViewController
    {
        public ViewController(IntPtr handle) : base(handle)
        {
        }

        public override void ViewDidLoad()
        {
            base.ViewDidLoad();
            MapView mapView = new MapView(View.Frame);
            View.Add(mapView);

            mapView.MapUnit = GeographyUnit.DecimalDegree;

            LayerOverlay layerOverlay = new LayerOverlay();
            mapView.Overlays.Add(layerOverlay);

            WmtsLayer wmtsLayer = new WmtsLayer();
            wmtsLayer.WmtsSeverEncodingType = WmtsSeverEncodingType.Restful;
            wmtsLayer.ServerUris.Add(new Uri("https://basemap.nationalmap.gov/arcgis/rest/services/USGSImageryOnly/MapServer/WMTS?"));
            wmtsLayer.ActiveLayerName = "USGSImageryOnly";
            wmtsLayer.ActiveStyleName = "default";
            wmtsLayer.TileMatrixSetName = "GoogleMapsCompatible";
            wmtsLayer.OutputFormat = "image/png";
            layerOverlay.Layers.Add(wmtsLayer);

            WmsRasterLayer wmsRasterLayer = new WmsRasterLayer(new Uri("http://demo.cubewerx.com/demo/cubeserv/simple"));
            wmsRasterLayer.ActiveLayerNames.Add("delay_3857");
            wmsRasterLayer.ActiveStyleNames.Add("generic");
            wmsRasterLayer.Crs = "EPSG:3857";
            wmsRasterLayer.OutputFormat = "image/png";
            wmsRasterLayer.IsTransparent = true;
            layerOverlay.Layers.Add(wmsRasterLayer);

            wmsRasterLayer.Open();
            mapView.CurrentExtent = wmsRasterLayer.GetBoundingBox();
            mapView.Refresh();
        }

        public override void DidReceiveMemoryWarning()
        {
            base.DidReceiveMemoryWarning();
            // Release any cached data, images, etc that aren't in use.
        }
    }
}